==> eha_1.2-0.tar.gz: eha/man/phfunc.Rd <==
\name{phfunc}
\alias{phfunc}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Loglihood function of a proportional hazards regression}
\description{
Calculates minus the log likelihood function and its first and second order
derivatives for data from a Weibull regression model. 
}
\usage{
phfunc(beta = NULL, lambda, p, X = NULL, Y, offset = rep(0, length(Y)),
ord = 2, pfixed = FALSE, dist = "weibull")
}

\arguments{
  \item{beta}{Regression parameters}
  \item{lambda}{The scale paramater}
  \item{p}{The shape parameter}
  \item{X}{The design (covariate) matrix.}
  \item{Y}{The response, a survival object.}
  \item{offset}{Offset.}
  \item{ord}{ord = 0 means only loglihood, 1 means score vector as well,
  2 loglihood, score and hessian.}
  \item{pfixed}{Logical, if TRUE the shape parameter is regarded as a known
  constant in the calculations, meaning that it is not cosidered in the
  partial derivatives.}
\item{dist}{Which distribtion? The default is "weibull", with the
  alternatives "loglogistic" and "lognormal".}
}
\details{
Note that the function returns log likelihood, score vector
and minus hessian, i.e. the observed information.
The model is
%\deqn{S(t; p, \lambda, \beta, z) = S_0((t / \lambda)^{p})^\exp(z\beta)}
}
\value{
A list with components
  \item{f}{The log likelihood. Present if \code{ord >= 0}}
  \item{fp}{The score vector. Present if \code{ord >= 1}}
  \item{fpp}{The negative of the hessian. Present if \code{ord >= 2}}
}
%\references{ }
\author{\enc{Gran Brostrm}{George Bridgewater}}
%\note{}

\seealso{\code{\link{phreg}}}
%\examples{
%}
\keyword{survival}
\keyword{distribution}

==> eha_2.2-0.tar.gz: eha/man/phfunc.Rd <==
\name{phfunc}
\alias{phfunc}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Loglihood function of a proportional hazards regression}
\description{
Calculates minus the log likelihood function and its first and second order
derivatives for data from a Weibull regression model. 
}
\usage{
phfunc(beta = NULL, lambda, p, X = NULL, Y, offset = rep(0, length(Y)),
ord = 2, pfixed = FALSE, dist = "weibull")
}

\arguments{
  \item{beta}{Regression parameters}
  \item{lambda}{The scale paramater}
  \item{p}{The shape parameter}
  \item{X}{The design (covariate) matrix.}
  \item{Y}{The response, a survival object.}
  \item{offset}{Offset.}
  \item{ord}{ord = 0 means only loglihood, 1 means score vector as well,
  2 loglihood, score and hessian.}
  \item{pfixed}{Logical, if TRUE the shape parameter is regarded as a known
  constant in the calculations, meaning that it is not cosidered in the
  partial derivatives.}
\item{dist}{Which distribtion? The default is "weibull", with the
  alternatives "loglogistic" and "lognormal".}
}
\details{
Note that the function returns log likelihood, score vector
and minus hessian, i.e. the observed information.
The model is
%\deqn{S(t; p, \lambda, \beta, z) = S_0((t / \lambda)^{p})^\exp(z\beta)}
}
\value{
A list with components
  \item{f}{The log likelihood. Present if \code{ord >= 0}}
  \item{fp}{The score vector. Present if \code{ord >= 1}}
  \item{fpp}{The negative of the hessian. Present if \code{ord >= 2}}
}
%\references{ }
\author{\enc{Göran Broström}{George Bridgewater}}
%\note{}

\seealso{\code{\link{phreg}}}
%\examples{
%}
\keyword{survival}
\keyword{distribution}
